# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).

## [In Progress](https://github.com/iamogbz/nvshim/pulls)

See open [issues](https://github.com/iamogbz/nvshim/issues)

## [Unreleased](https://github.com/iamogbz/nvshim/releases)

See closed [issues](https://github.com/iamogbz/nvshim/pulls?q=is%3Apr+is%3Amerged+sort%3Acreated-desc+-label%3Areleased)

## [1.0.5](https://github.com/iamogbz/nvshim/compare/v1.0.4...v1.0.5) (2020-04-07)


### Bug Fixes

* handle process interruption gracefully ([#73](https://github.com/iamogbz/nvshim/issues/73)) ([3237c96](https://github.com/iamogbz/nvshim/commit/3237c965b15b684c7ca813db4c94aa1ed557514d))
